@@ -35,7 +35,12 @@ sub BUILD {
             };
         };
 
+        container 'Controller' => as {
+            container 'Foo' => as {
+                service bar => 42;
+            },
+        };
     };
 }
 
-no Bread::Board; no Moose; 1;
\ No newline at end of file
+no Bread::Board; no Moose; 1;
